<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Lentotila käytössä</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Lentotila suljettu</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Käyttöön</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Lentotilan asetukset</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Omat laitteet</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Pois päältä</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
        <translation>Poista ensin &quot;Lentotila&quot; käytöstä, jos haluat muodostaa bluetooth yhteyden</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yhdistetty</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Pois päältä</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Yhdistetty %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Kirkkaus</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Näytön asetukset</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Näytön asetukset</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Kirkkaus</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Su</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Ti</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Ke</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>To</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pe</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>La</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Lisää näppäimistön asettelu</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Kello</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12h</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24h</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Kello asetukset</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Avaa kalenteri</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Maanantai</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tiistai</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Keskiviikko</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torstai</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Perjantai</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Lauantai</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sunnuntai</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maanantai</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tiistai</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>keskiviikko</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>torstai</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>perjantai</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>lauantai</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sunnuntai</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Muut laitteet</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Älä häiritse</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Älä häiritse asetukset</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Suljettu</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Käyttöön</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Älä häiritse käytössä</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Älä häiritse suljettu</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Älä häiritse</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Silmien mukavuutta</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Silmien mukavuus käytössä</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Silmien mukavuus suljettu</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Näytön asetukset</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Silmien mukavuus</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Teema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Päällä</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Pois</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom.</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Poista silmien mukavuus käytöstä</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Ota silmien mukavuus käyttöön</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Näytön asetukset</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Teema: vaalea</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Teema: tumma</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Teema: autom.</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Visuaalinen tehoste</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Autom.</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Teema</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Piilota automaattisesti</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Paneeli asetukset</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Ei viestejä</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Ilmoitukset</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Poista DND käytöstä</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Kytke DND käyttöön</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Ilmoitus</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Korkea suoritusteho</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Tasapainoinen</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Virransäästö</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Tasapainoinen suoritusteho</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Asetukset virta</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akku %1, %2 min jäljellä</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akku %1, %2 t %3 min jäljellä</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Lataa %1, %2 min täyteen</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Lataa %1, %2 t %3 min täyteen</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Varaus %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ladataan: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Varaus %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Varaus %1, täyteen ladattu</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Varaus %1, ei ladata</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Akku</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Latauksessa, avioitu latausaika</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Jäljellä olevan käyttöaika</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 min jäljellä</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 h %2 min jäljellä</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Ei latauksessa</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Täyteen ladattu</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Ladataan, %1 min täyteen</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Ladataan, %1 h %2 min täyteen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Akku %1, %2 h jäljellä</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 h jäljellä</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Lataa %1, %2 h täyteen</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Ladataan, %1 h täyteen</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Virta-asetukset</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Tuntematon</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Virta-asetukset</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Päivitä ja sammuta</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Päivitä ja käynnistä</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Kuu</translation>
    </message>
    <message>
        <source>y</source>
        <translation>v</translation>
    </message>
    <message>
        <source>m</source>
        <translation>kk</translation>
    </message>
    <message>
        <source>d</source>
        <translation>pv</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Maanantai</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tiistai</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Keskiviikko</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torstai</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Perjantai</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Lauantai</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sunnuntai</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Tammikuu</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Helmikuu</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Maaliskuu</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Huhtikuu</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Toukokuu</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Kesäkuu</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Heinäkuu</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Elokuu</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Syyskuu</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Lokakuu</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Marraskuu</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Joulukuu</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Avaa kalenteri</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maanantai</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tiistai</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>keskiviikko</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>torstai</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>perjantai</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>lauantai</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sunnuntai</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Voimakkuus</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Ulostulo</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Äänen asetukset</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Poista mykistys</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mykistä</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Äänen asetukset</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Ei ulostulon laitteita</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Voimakkuus %1</translation>
    </message>
</context>
</TS>